;; Generated package description from paredit.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "paredit" "27beta0.20241103.20" "minor mode for editing parentheses" 'nil :commit "af075775af91f2dbc63b915d762b4aec092946c4" :authors '(("Taylor R. Campbell" . "campbell@paredit.org")) :maintainer '("Taylor R. Campbell" . "campbell@paredit.org") :keywords '("lisp") :url "https://paredit.org")
